@@ -111,6 +111,12 @@ class AbstractSecurityManager(BaseManager):
     def security_cleanup(self, baseviews, menus):
         raise NotImplementedError
 
+    def get_first_user(self):
+        raise NotImplementedError
+
+    def noop_user_update(self, user) -> None:
+        raise NotImplementedError
+
 
 def _oauth_tokengetter(token=None):
     """
@@ -814,12 +820,12 @@ class BaseSecurityManager(AbstractSecurityManager):
 
     def update_user_auth_stat(self, user, success=True):
         """
-            Update authentication successful to user.
+        Update authentication successful to user.
 
-            :param user:
-                The authenticated user model
-            :param success:
-                Default to true, if false increments fail_login_count on user model
+        :param user:
+            The authenticated user model
+        :param success:
+            Default to true, if false increments fail_login_count on user model
         """
         if not user.login_count:
             user.login_count = 0
@@ -835,18 +841,22 @@ class BaseSecurityManager(AbstractSecurityManager):
 
     def auth_user_db(self, username, password):
         """
-            Method for authenticating user, auth db style
+        Method for authenticating user, auth db style
 
-            :param username:
-                The username or registered email address
-            :param password:
-                The password, will be tested against hashed password on db
+        :param username:
+            The username or registered email address
+        :param password:
+            The password, will be tested against hashed password on db
         """
         if username is None or username == "":
             return None
+        first_user = self.get_first_user()
         user = self.find_user(username=username)
         if user is None:
             user = self.find_user(email=username)
+        else:
+            # Balance failure and success
+            _ = self.find_user(email=username)
         if user is None or (not user.is_active):
             # Balance failure and success
             check_password_hash(
@@ -855,6 +865,8 @@ class BaseSecurityManager(AbstractSecurityManager):
                 "password",
             )
             log.info(LOGMSG_WAR_SEC_LOGIN_FAILED.format(username))
+            # Balance failure and success
+            self.noop_user_update(first_user)
             return None
         elif check_password_hash(user.password, password):
             self.update_user_auth_stat(user, True)
